@@ -7,7 +7,7 @@ use strict;
 
 package POSIX::1003::Pathconf;
 use vars '$VERSION';
-$VERSION = '0.10';
+$VERSION = '0.11';
 
 use base 'POSIX::1003';
 
@@ -32,6 +32,16 @@ BEGIN {
     tie %pathconf, 'POSIX::1003::ReadOnlyTable', $pathconf;
 }
 
+sub pathconf($$);
+
+
+sub exampleValue($)
+{   my ($class, $name) = @_;
+    $name =~ m/^_PC_/ or return;
+    my $val = pathconf __FILE__, $name;
+    defined $val ? $val : 'undef';
+}
+
 
 sub fpathconf($$)
 {   my ($fd, $key) = @_;
