@@ -7,7 +7,7 @@ use strict;
 
 package POSIX::1003::Properties;
 use vars '$VERSION';
-$VERSION = '0.10';
+$VERSION = '0.11';
 
 use base 'POSIX::1003';
 
@@ -32,6 +32,16 @@ BEGIN {
     tie %property, 'POSIX::1003::ReadOnlyTable', $property;
 }
 
+sub property($);
+
+
+sub exampleValue($)
+{   my ($class, $name) = @_;
+    $name =~ m/^_POSIX/ or return;
+    my $val = property $name;
+    defined $val ? $val : 'undef';
+}
+
 
 sub property($)
 {   my $key = shift // return;
