@@ -7,7 +7,7 @@ use strict;
 
 package POSIX::1003::Signals;
 use vars '$VERSION';
-$VERSION = '0.10';
+$VERSION = '0.11';
 
 use base 'POSIX::1003';
 
@@ -27,12 +27,12 @@ my @functions = qw/
  signal_names
  /;
 
-my @constants = (@signals, @actions);
+my @constants = (@signals, @states, @actions);
 
 our %EXPORT_TAGS =
   ( signals   => \@signals
   , actions   => \@actions
-  , states    => \@states
+  , status    => \@states
   , constants => \@constants
   , functions => \@functions
   , table     => [ '%signals' ]
